You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@pdfbox.apache.org by ti...@apache.org on 2020/08/11 17:18:59 UTC

svn commit: r1880783 - in /pdfbox/branches/1.8/pdfbox/src/test: java/org/apache/pdfbox/filter/TestFilters.java resources/org/apache/pdfbox/filter/PDFBOX-1777.bin resources/org/apache/pdfbox/filter/PDFBOX-1977.bin

Author: tilman
Date: Tue Aug 11 17:18:59 2020
New Revision: 1880783

URL: http://svn.apache.org/viewvc?rev=1880783&view=rev
Log:
PDFBOX-4933: very late correction to actual issue number

Added:
    pdfbox/branches/1.8/pdfbox/src/test/resources/org/apache/pdfbox/filter/PDFBOX-1977.bin
      - copied unchanged from r1880516, pdfbox/branches/1.8/pdfbox/src/test/resources/org/apache/pdfbox/filter/PDFBOX-1777.bin
Removed:
    pdfbox/branches/1.8/pdfbox/src/test/resources/org/apache/pdfbox/filter/PDFBOX-1777.bin
Modified:
    pdfbox/branches/1.8/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java

Modified: pdfbox/branches/1.8/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java
URL: http://svn.apache.org/viewvc/pdfbox/branches/1.8/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java?rev=1880783&r1=1880782&r2=1880783&view=diff
==============================================================================
--- pdfbox/branches/1.8/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java (original)
+++ pdfbox/branches/1.8/pdfbox/src/test/java/org/apache/pdfbox/filter/TestFilters.java Tue Aug 11 17:18:59 2020
@@ -120,17 +120,17 @@ public class TestFilters extends TestCas
 
 
     /**
      * This will test the LZW filter with the sequence that failed in PDFBOX-1777.
      * To check that the test itself is legit, revert LZWFilter.java to rev 1571801,
      * which should fail this test.
      * 
      * @throws IOException 
      */
-    public void testPDFBOX1777() throws IOException
+    public void testPDFBOX1977() throws IOException
     {
         LZWFilter lzwFilter = new LZWFilter();
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
-        InputStream is = this.getClass().getResourceAsStream("PDFBOX-1777.bin");
+        InputStream is = this.getClass().getResourceAsStream("PDFBOX-1977.bin");
         int by;
         while ((by = is.read()) != -1)
         {
@@ -120,17 +120,17 @@ public class TestFilters extends TestCas
 
     /**
-     * This will test the LZW filter with the sequence that failed in PDFBOX-1777.
+     * This will test the LZW filter with the sequence that failed in PDFBOX-1977.
      * To check that the test itself is legit, revert LZWFilter.java to rev 1571801,
      * which should fail this test.